Index: trunk/MagicSoft/Mars/mpointing/MPointingPos.cc
===================================================================
--- trunk/MagicSoft/Mars/mpointing/MPointingPos.cc	(revision 3592)
+++ trunk/MagicSoft/Mars/mpointing/MPointingPos.cc	(revision 3666)
@@ -73,4 +73,4 @@
 Double_t MPointingPos::RotationAngle(const MObservatory &o, const MTime &t) const
 {
-    return MAstroSky2Local(t, o).RotationAngle(fRa*TMath::DegToRad()*15, fDec*TMath::DegToRad());
+    return MAstroSky2Local(t, o).RotationAngle(GetRaRad(), GetDecRad());
 }
Index: trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.cc	(revision 3592)
+++ trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.cc	(revision 3666)
@@ -46,4 +46,7 @@
 // To be done:
 //   - wobble mode missing
+//   - a switch between using sky-coordinates and time or local-coordinates
+//     from MPointingPos for determin the rotation angle
+//   - the center of rotation need not to be the camera center
 //
 //////////////////////////////////////////////////////////////////////////////
@@ -101,4 +104,11 @@
     {
         *fLog << err << "MObservatory not found... aborting." << endl;
+        return kFALSE;
+    }
+
+    fTime = (MTime*)pList->FindObject("MTime");
+    if (!fTime)
+    {
+        *fLog << err << "MTime not found... aborting." << endl;
         return kFALSE;
     }
@@ -166,10 +176,10 @@
         return kTRUE;
 
+    // rotate the source position by the current rotation angle
+    const Double_t rho = fPointPos->RotationAngle(*fObservatory, *fTime);
+
     // Define source position in the camera plain
     TVector2 v(fX, fY);
-
-    // rotate the source position by the current rotation angle
-    const Double_t rho = fPointPos->RotationAngle(*fObservatory);
-    v=v.Rotate(-rho);
+    v=v.Rotate(rho);
 
     // Convert coordinates into camera plain (mm)
Index: trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.h
===================================================================
--- trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.h	(revision 3592)
+++ trunk/MagicSoft/Mars/mpointing/MSrcPosCalc.h	(revision 3666)
@@ -10,4 +10,5 @@
 class MSrcPosCam;
 class MGeomCam;
+class MTime;
 
 class MSrcPosCalc : public MTask
@@ -18,4 +19,5 @@
     MSrcPosCam   *fSrcPos;
     MGeomCam     *fGeom;
+    MTime        *fTime;
 
     Double_t fR;    // Distance of source to a fitted star
@@ -32,4 +34,5 @@
     MSrcPosCalc(const char *name=NULL, const char *title=NULL);
 
+    // Use is deprecated!
     void SetOffset(Double_t r, Double_t drho)
     {

Index: trunk/MagicSoft/Mars/mpointing/MPointingPos.h
===================================================================
--- trunk/MagicSoft/Mars/mpointing/MPointingPos.h	(revision 3592)
+++ trunk/MagicSoft/Mars/mpointing/MPointingPos.h	(revision 3666)
@@ -15,13 +15,13 @@
     Double_t fAz;  // [deg] Azimuth
 
-    Double_t fRa;  // [rad] Right ascension
-    Double_t fHa;  // [rad] Hour angle
-    Double_t fDec; // [rad] Declination
+    Double_t fRa;  // [h]   Right ascension
+    Double_t fHa;  // [h]   Hour angle
+    Double_t fDec; // [deg] Declination
 
 public:
-    MPointingPos()
+    MPointingPos(const char *name=0, const char *title=0)
     {
-        fName  = "MPointingPos";
-        fTitle = "Container storing the (corrected) telescope pointing position";
+        fName  = name ? name   : "MPointingPos";
+        fTitle = title ? title : "Container storing the (corrected) telescope pointing position";
     }
 
@@ -35,6 +35,13 @@
     Double_t GetDec() const { return fDec; }
 
+    Double_t GetRaRad() const  { return fRa*TMath::DegToRad()*15; }
+    Double_t GetDecRad() const { return fDec*TMath::DegToRad(); }
+
     Double_t RotationAngle(const MObservatory &o) const;
     Double_t RotationAngle(const MObservatory &o, const MTime &t) const;
+    Double_t RotationAngle(const MObservatory &o, const MTime *t) const
+    {
+        return t ? RotationAngle(o, *t) : RotationAngle(o);
+    }
 
     ClassDef(MPointingPos, 1) //Container storing the (corrected) telescope pointing position